unquad.strategy.split.Split
===========================

.. currentmodule:: unquad.strategy.split

.. autoclass:: Split

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Split.__init__
      ~Split.fit_calibrate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Split.calibration_ids
   
   